pub struct MoveGenPreprocessing(/* private fields */);Expand description
Contains data about checkers, pinned pieces, and pinners
If you need to verify if a position is in check before generating legal moves then using movegen_preprocessing() followed by legal_moves_with_preprocessing() will save some time. eg:
let movegen_data = movegen_preprocessing(position); if movegen_data.in_check() { // …do something } legal_moves_with_preprocessing(list, data);
Implementations