pub struct PieceSquareTable { /* private fields */ }Expand description
PieceSquareTable gives scores for pieces on squares from the perspective of white. See https://www.chessprogramming.org/Piece-Square_Tables
Implementations
Sourceimpl PieceSquareTable
impl PieceSquareTable
Sourcepub fn new(piece_square_values: [[i16; 64]; 6]) -> PieceSquareTable
pub fn new(piece_square_values: [[i16; 64]; 6]) -> PieceSquareTable
piece_square_values should encode positional and material value of piece on each square. eg if pawn is worth +100 material value and pawn on D4 is worth +20 as positional value, entry for pawn on D4 should equal 100 + 20 = +120.
pub fn castle_score(&self, castle: Castle) -> i16